# polars-lazy

`polars-lazy` is a lazy query engine for the Polars DataFrame library. It allows you to perform operations on DataFrames in a lazy manner, only executing them when necessary. This can lead to significant performance improvements for large datasets.

## Features

Please refer to the parent `polars` crate for a comprehensive list of features.
